/*	$UxDriver: am79c930reg.h,v 1.15 1999/04/15 04:31:32 cas Exp $	*/

/*
 * Copyright (c) 1998,1999 Trans New Technology, Inc. and
 *                         Hiroki NAKANO <cas@trans-nt.com>
 * All rights reserved.
 *
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that this notice is retained,
 * the conditions in the following notices are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by
 *	Trans New Technology, Inc. (in Japan)
 *
 *
 * THIS SOFTWARE IS PROVIDED BY TRANS NEW TECHNOLOGY, INC. ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL TRANS NEW TECHNOLOGY, INC. BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

/*
 * ICOM UX-136 Wireless LAN Card
 *   (AMD Am79C930 IEEE802.11 Firmware API ver.1.0)
 *
 *	Am79C930 chip spec
 */

/* IO Registers */

#define	AM79C930_IOREG_SIRS		0	/* the First SIR */
#define	AM79C930_IOREG_SIR(n)		(n)
#define	AM79C930_IOREG_TIRS		8	/* the First TIR */
#define	AM79C930_IOREG_TIR(n)		(8 + (n))

#define	AM79C930_IOREG_GCR		0	/* SIR 0 */
#define	AM79C930_IOREG_BSS		1	/* SIR 1 */
#define	AM79C930_IOREG_LMAL		2	/* SIR 2 */
#define	AM79C930_IOREG_LMAU		3	/* SIR 3 */
#define	AM79C930_IOREG_DPLL		4	/* SIR 4 */
#define	AM79C930_IOREG_DPLM		5	/* SIR 5 */
#define	AM79C930_IOREG_DPUM		6	/* SIR 6 */
#define	AM79C930_IOREG_DPUU		7	/* SIR 7 */

/* Detail Description of IO Registers */ 

#define	AM79C930_IOREG_GCR_SWRESET	(1U<<7)
#define	AM79C930_IOREG_GCR_CORESET	(1U<<6)
#define	AM79C930_IOREG_GCR_DISPWDN	(1U<<5)
#define	AM79C930_IOREG_GCR_ECWAIT	(1U<<4)
#define	AM79C930_IOREG_GCR_ECINT	(1U<<3)
#define	AM79C930_IOREG_GCR_INT2EC	(1U<<2)
#define	AM79C930_IOREG_GCR_ENECINT	(1U<<1)
#define	AM79C930_IOREG_GCR_DAM		(1U<<0)

#define	AM79C930_IOREG_BSS_ECATR	(1U<<7)
#define	AM79C930_IOREG_BSS_FS		(1U<<5)
#define	AM79C930_IOREG_BSS_MBS_MASK	(3U<<3)
#define	AM79C930_IOREG_BSS_MBS_SHIFT	3
#define	AM79C930_IOREG_BSS_EIOW		(1U<<2)
#define	AM79C930_IOREG_BSS_TBS_MASK	(3U<<0)
#define	AM79C930_IOREG_BSS_TBS_SHIFT	0

#define	AM79C930_IOREG_LMAU_ISAPWRDWN	(1U<<7)
#define	AM79C930_IOREG_LMAU_TBS_MASK	0x7f
#define	AM79C930_IOREG_LMAU_TBS_SHIFT	0

/* Memory Map and Structures */

#define	AM79C930_ADDR_LAST_COMPLETED_DESCRIPTOR_BLOCK	0x03ec
#define	AM79C930_ADDR_BANNER				0x0480
#define	AM79C930_ADDR_COMMAND_BLOCK			0x04a0
#define	AM79C930_ADDR_CONTROL_STATUS_BLOCK		0x04f0
#define	AM79C930_ADDR_VIRTUAL_BIT_MAP			0x0500
#define	AM79C930_ADDR_BUFFER_SPACE			0x0600
#define	AM79C930_ADDR_BUFFER_SPACE_LAST			0x6800


#define	Am79C930_Last_Completed_Descriptor_Block_STRUCTSIZE 20
struct	Am79C930_Last_Completed_Descriptor_Block {
	ux_uint32_t	Last_Bcast_Tx_Desc;
	ux_uint32_t	Last_Mgnt_Tx_Desc;
	ux_uint32_t	Last_Data_Tx_Desc;
	ux_uint32_t	Last_PS_Poll_Tx_Desc;
	ux_uint32_t	Last_CF_Poll_Tx_Desc;
};

#define Am79C930_Banner_STRUCTSIZE 32
struct	Am79C930_Banner {
	unsigned char	Banner[32];
};

#define	Am79C930_Command_Block_STRUCTSIZE 80
struct	Am79C930_Command_Block {
	ux_uint8_t	Command;
	ux_uint8_t	Command_Status;
	ux_uint8_t	Error_Offset;
	ux_uint8_t	Reserved;
	ux_uint8_t	Command_Parameters[76];
};

#define	Am79C930_Control_Status_Block_STRUCTSIZE 16
struct	Am79C930_Control_Status_Block {
	ux_uint8_t	Self_Test_Status;	/* Read only */
	ux_uint8_t	STA_State;		/* Read only */
	ux_uint8_t	Rsvd_For_User_Rtn;
	ux_uint8_t	Interrupt_Status;
	ux_uint8_t	Interrupt_Mask;
	ux_uint8_t	Lockout_PCnet_MOBILE;
	ux_uint8_t	Lockout_Host;		/* Read only */
	ux_uint8_t	Interrupt_Status2;
	ux_uint32_t	Reserved;
	ux_uint8_t	SW_Dis_Pwr_Dn;
	ux_uint8_t	Interrupt_Mask2;
	ux_uint8_t	Driver_State;
	ux_uint8_t	Reserved2;
};

#define	AM79C930_INTR_WAKING_UP		(1<<7)
#define	AM79C930_INTR_CFP_ENDING	(1<<6)
#define	AM79C930_INTR_DTIM		(1<<5)
#define	AM79C930_INTR_CFP_STARTING	(1<<4)
#define	AM79C930_INTR_SCAN_CMPLT	(1<<3)
#define	AM79C930_INTR_TX		(1<<2)
#define	AM79C930_INTR_RX		(1<<1)
#define	AM79C930_INTR_CMND		(1<<0)

#define	AM79C930_INTR2_RX_PS_POLL_MGMT	(1<<7)
#define	AM79C930_INTR2_RX_DATA		(1<<6)
#define	AM79C930_INTR2_TX_MGMT		(1<<4)
#define	AM79C930_INTR2_TX_CF_POLL	(1<<3)
#define	AM79C930_INTR2_TX_PS_POLL	(1<<2)
#define	AM79C930_INTR2_TX_BCAST		(1<<1)
#define	AM79C930_INTR2_TX_DATA		(1<<0)

#define	AM79C930_INTR2_SHIFT		8
#define	AM79C930_INTR_RX_PS_POLL_MGMT	(AM79C930_INTR2_RX_PS_POLL_MGMT	<< AM79C930_INTR2_SHIFT)
#define	AM79C930_INTR_RX_DATA		(AM79C930_INTR2_RX_DATA		<< AM79C930_INTR2_SHIFT)
#define	AM79C930_INTR_TX_MGMT		(AM79C930_INTR2_TX_MGMT		<< AM79C930_INTR2_SHIFT)
#define	AM79C930_INTR_TX_CF_POLL	(AM79C930_INTR2_TX_CF_POLL	<< AM79C930_INTR2_SHIFT)
#define	AM79C930_INTR_TX_PS_POLL	(AM79C930_INTR2_TX_PS_POLL	<< AM79C930_INTR2_SHIFT)
#define	AM79C930_INTR_TX_BCAST		(AM79C930_INTR2_TX_BCAST	<< AM79C930_INTR2_SHIFT)
#define	AM79C930_INTR_TX_DATA		(AM79C930_INTR2_TX_DATA		<< AM79C930_INTR2_SHIFT)

/* Commands */

#define	AM79C930_CMD_TEST_INTERFACE_NOP		1
#define	AM79C930_CMD_SET_MIB_VARIABLES		2
#define	AM79C930_CMD_INIT_TX			3
#define	AM79C930_CMD_FLUSH_TX			4
#define	AM79C930_CMD_ENABLE_RECEIVER		5
#define	AM79C930_CMD_DISABLE_RECEIVER		6
#define	AM79C930_CMD_SLEEP			7
#define	AM79C930_CMD_WAKE			8
#define	AM79C930_CMD_GET_MIB_VARIABLES		9
#define	AM79C930_CMD_SCAN			10
#define	AM79C930_CMD_SYNC			11
#define	AM79C930_CMD_RESUME			12

#define	AM79C930_CMDSTAT_IDLE			0
#define	AM79C930_CMDSTAT_COMPLETED		1
#define	AM79C930_CMDSTAT_REJECTED_UNKNOWN	2
#define	AM79C930_CMDSTAT_REJECTED_INVALIDPARAM	3
#define	AM79C930_CMDSTAT_REJECTED_NOSUPPORT	4
#define	AM79C930_CMDSTAT_REJECTED_INVALIDRESULT	5
#define	AM79C930_CMDSTAT_REJECTED_INVALIDMODE	6

#define	Am79C930_CmdParam_Set_MIB_Variables_STRUCTSIZE 76
struct	Am79C930_CmdParam_Set_MIB_Variables {
	ux_uint8_t	Type;
	ux_uint8_t	Size;
	ux_uint8_t	Index;
	ux_uint8_t	Reserved;
	ux_uint8_t	Data[72];
};

#define	Am79C930_CmdParam_Init_Tx_STRUCTSIZE 20
struct	Am79C930_CmdParam_Init_Tx {
	ux_uint32_t	Data_Desc;
	ux_uint32_t	Mgmt_Desc;
	ux_uint32_t	Broadcast_Desc;
	ux_uint32_t	PS_Poll_Desc;
	ux_uint32_t	CF_Poll_Desc;
};

#define	Am79C930_CmdParam_Flush_Tx_STRUCTSIZE 20
struct	Am79C930_CmdParam_Flush_Tx {
	ux_uint32_t	Data;
	ux_uint32_t	Management;
	ux_uint32_t	Broadcast;
	ux_uint32_t	PS_Poll;
	ux_uint32_t	CF_Poll;
};

#define	Am79C930_CmdParam_Enable_Receiver_STRUCTSIZE 8
struct 	Am79C930_CmdParam_Enable_Receiver {
	ux_uint32_t	Data_Desc;
	ux_uint32_t	PS_Poll_Mgmt_Desc;
};

#define	Am79C930_CmdParam_Sleep_STRUCTSIZE 8
struct	Am79C930_CmdParam_Sleep {
	ux_uint64_t	Wake_Up_Time;
};

#define	Am79C930_CmdParam_Get_MIB_Variables_STRUCTSIZE 76
struct	Am79C930_CmdParam_Get_MIB_Variables {
	ux_uint8_t	Type;
	ux_uint8_t	Size;
	ux_uint8_t	Index;
	ux_uint8_t	Reserved;
	ux_uint8_t	Data[72];
};

#define	Am79C930_CmdParam_Scan_STRUCTSIZE 6
struct	Am79C930_CmdParam_Scan {
	ux_uint16_t	Duration;
	ux_uint8_t	Set_Channel;
	ux_uint8_t	Pattern;
	ux_uint8_t	Index;
	ux_uint8_t	Suspend;
};

#define	Am79C930_CmdParam_Sync_STRUCTSIZE 20
struct	Am79C930_CmdParam_Sync {
	ux_uint8_t	Set_Channel;
	ux_uint8_t	Pattern;
	ux_uint8_t	Index;
	ux_uint8_t	Start_BSS;
	ux_uint16_t	Dwell_Interval;
	ux_uint16_t	Reserved;		/* must be 0 */
	ux_uint64_t	BSS_timestamp;
	ux_uint32_t	Ref_Time;
};

/* Descriptors of Queue */

#define	Am79C930_Rx_Desc_STRUCTSIZE 24
struct	Am79C930_Rx_Desc {
	ux_uint32_t	Reserved1;
	ux_uint32_t	Next_Descriptor;
	ux_uint8_t	Reserved2;
	ux_uint8_t	Host_Desc_State;
#define	AM79C930_RX_DESC_STATE_OWN		(1<<7)	/* 0:host 1:firmware */
#define	AM79C930_RX_DESC_STATE_CONSUMED		(1<<6)
#define	AM79C930_RX_DESC_STATE_LAST_FRAGMENT	(1<<5)
#define	AM79C930_RX_DESC_STATE_CRC		(1<<3)
#define	AM79C930_RX_DESC_STATE_BUFFER_OFLO	(1<<1)
#define	AM79C930_RX_DESC_STATE_RXERROR		(1<<0)

	ux_uint8_t	RSSI;
	ux_uint8_t	Index;
	ux_uint32_t	Local_Time;

	ux_uint32_t	Rx_Start_of_Frame;
	ux_uint16_t	Rx_Length;
	ux_uint8_t	Rate;
	ux_uint8_t	Reserved3;
};

#define	Am79C930_Tx_Desc_STRUCTSIZE 24
struct	Am79C930_Tx_Desc {
	ux_uint32_t	Tx_Start_of_Frame;
	ux_uint32_t	Next_Descriptor;
	ux_uint16_t	Tx_Length;
	ux_uint8_t	Tx_State;
#define	AM79C930_TX_DESC_STATE_OWN		(1<<7)	/* 0:host 1:firmware */
#define	AM79C930_TX_DESC_STATE_DONE		(1<<6)
#define	AM79C930_TX_DESC_STATE_REJECTED		(1<<5)
#define	AM79C930_TX_DESC_STATE_MSDU_TMOUT	(1<<4)
#define	AM79C930_TX_DESC_STATE_ABRT		(1<<3)
#define	AM79C930_TX_DESC_STATE_RETURNED		(1<<2)
#define	AM79C930_TX_DESC_STATE_RETRY		(1<<1)
#define	AM79C930_TX_DESC_STATE_TXERROR		(1<<0)
	ux_uint8_t	Tx_Rate;
	ux_uint8_t	Num_DIFS_Attempts;
	ux_uint8_t	Num_DIFS_Failures;
	ux_uint8_t	Num_SIFS_Attempts;
	ux_uint8_t	Num_SIFS_Failures;
	ux_uint32_t	Reserved;
	ux_uint8_t	Num_RTS_Attempts;
	ux_uint8_t	Num_Data_Attempts;
	ux_uint8_t	Control;
#define	AM79C930_TX_DESC_CONTROL_PSNO		(1<<7)
#define	AM79C930_TX_DESC_CONTROL_BURST		(1<<1)
#define	AM79C930_TX_DESC_CONTROL_FRAGS		(1<<0)
	ux_uint8_t	Reserved2;
};

/* ESSID */

#define	Am79C930_ESS_ID_STRUCTSIZE	34
struct	Am79C930_ESS_ID {
	ux_uint8_t	Type;
	ux_uint8_t	Length;
	ux_uint8_t	Data[32];
};

/* MIBs */

#define	AM79C930_MIB_LOCAL_MIB			0
#define	AM79C930_MIB_MAC_ADDRESS_STATUS_GRP	2
#define	AM79C930_MIB_MAC_MIB			3
#define	AM79C930_MIB_MAC_STATISTIC_MIB		4
#define	AM79C930_MIB_MAC_MGMT_MIB		5
#define	AM79C930_MIB_DRVR_MAC_MGMT_MIB		6
#define	AM79C930_MIB_PHY_MIB			7

#define	Am79C930_Local_MIB_STRUCTSIZE 32
struct	Am79C930_Local_MIB {
	ux_uint8_t	Fragmentation_Dis;
	ux_uint8_t	Add_PLCP_Dis;
	ux_uint8_t	MAC_Hdr_Prsv;
	ux_uint8_t	Rx_Mgmt_Que_En;

	ux_uint8_t	Re_Assembly_Dis;
	ux_uint8_t	Strip_PLCP_Dis;
	ux_uint8_t	Rx_Error_Dis;
	ux_uint8_t	Power_Saving_Mode_Dis;
	ux_uint8_t	Accept_All_Multicast_Dis;
	ux_uint8_t	Check_Seq_Cntl_Dis;

	ux_uint8_t	Flush_CFP_Queue_On_CF_End;
	ux_uint8_t	Network_Mode;
	ux_uint8_t	PWD_Lvl;
	ux_uint8_t	CFP_Mode;

	ux_uint32_t	Tx_Buffer_Offset;
	ux_uint32_t	Tx_Buffer_Size;
	ux_uint32_t	Rx_Buffer_Offset;
	ux_uint32_t	Rx_Buffer_Size;

	ux_uint8_t	Acting_as_AP;
	ux_uint8_t	Fill_CFP;
} __attribute__((packed));	/* GCC extension */

#define	Am79C930_MAC_Address_Status_grp_STRUCTSIZE 32
struct	Am79C930_MAC_Address_Status_grp {
	ux_uint48_t	aMAC_Address;
	ux_uint48_t	aGroup_Addresses[4];

	ux_uint8_t	aTransmit_Enable_Status;
	ux_uint8_t	Reserved;
};

#define	Am79C930_MAC_MIB_STRUCTSIZE 72
struct	Am79C930_MAC_MIB {
	ux_uint16_t	Reserved1;
	ux_uint16_t	Reserved2;

	ux_uint16_t	aRTS_Threshold;

	ux_uint16_t	aCW_max;
	ux_uint16_t	aCW_min;

	ux_uint8_t	aPromiscuous_Enable;
	ux_uint8_t	Reserved3;
	ux_uint32_t	Reserved4;

	ux_uint8_t	aShort_Retry_Limit;
	ux_uint8_t	aLong_Retry_Limit;

	ux_uint16_t	aMax_Frame_Length;

	ux_uint16_t	aFragmentation_Threshold;

	ux_uint16_t	aProbe_Delay;
	ux_uint16_t	aMin_Probe_Response_Time;
	ux_uint16_t	aMax_Probe_Response_Time;

	ux_uint32_t	aMax_Transmit_MSDU_Lifetime;
	ux_uint32_t	aMax_Receive_MSDU_Lifetime;

	ux_uint16_t	aStation_Basic_Rate;
	struct Am79C930_ESS_ID	aDesired_ESS_ID;
/*	ux_uint8_t	aDesired_ESS_ID[AM79C930_ESS_ID_SIZE];	*/
};

#define	Am79C930_MAC_Statistic_MIB_STRUCTSIZE 68
struct	Am79C930_MAC_Statistic_MIB {
	ux_uint32_t	aTransmitted_MPDU_Count;
	ux_uint32_t	aTransmitted_MSDU_Count;
	ux_uint32_t	aOctets_Transmitted_Cnt;
	ux_uint16_t	aMulticast_Transmitted_Frame_Count;
	ux_uint16_t	aBroadcast_Transmitted_Frame_Count;

	ux_uint32_t	aFailed_Count;
	ux_uint32_t	aRetry_Count;

	ux_uint32_t	aMultiple_Retry_Count;

	ux_uint32_t	aFrame_Duplicate_Count;

	ux_uint32_t	aRTS_Success_Count;
	ux_uint32_t	aRTS_Failure_Count;
	ux_uint32_t	aACK_Failure_Count;

	ux_uint32_t	aReceived_Frame_Count;
	ux_uint32_t	aOctets_Received_Count;
	ux_uint16_t	aMulticast_Received_Count;
	ux_uint16_t	aBroadcast_Received_Count;

	ux_uint32_t	aFCS_Error_Count;
	ux_uint32_t	aError_Count;
	ux_uint32_t	aWEP_Undecryptable_Count;
};

#define	Am79C930_MAC_Mgmt_MIB_STRUCTSIZE 64
struct	Am79C930_MAC_Mgmt_MIB {
	ux_uint8_t	aPower_Mgt_Mode;
	ux_uint8_t	aScan_Mode;
	ux_uint8_t	aScan_State;
	ux_uint8_t	aDTIM_Period;
	ux_uint16_t	aATIM_Window;
	ux_uint8_t	Wep_Required;
	ux_uint8_t	Reserved;
	ux_uint16_t	aBeacon_Period;
	ux_uint16_t	aPassive_Scan_Duration;
	ux_uint16_t	aListen_Interval;
	ux_uint16_t	aMedium_Occupancy_Limit;
	ux_uint16_t	aMax_MPDU_Time;
	ux_uint16_t	aCFP_Max_Duration;
	ux_uint8_t	aCFP_Rate;
	ux_uint8_t	Do_Not_Receive_DTIMs;
	ux_uint16_t	aStation_ID;
	ux_uint48_t	aCurrent_BSS_ID;
	struct Am79C930_ESS_ID	aCurrent_ESS_ID;
/*	ux_uint8_t	aCurrent_ESS_ID[AM79C930_ESS_ID_SIZE];	*/
};

#define	AM79C930_NUM_DEFAULT_WEP_KEYS	1	/* XXX */
#define	AM79C930_NUM_WEP_KEY_MAPPINGS	1	/* XXX */
#define	AM79C930_NUM_KNOWN_APS		1	/* XXX */

#define	Am79C930_Drvr_MAC_Mgmt_MIB_STRUCTSIZE 24
struct	Am79C930_Drvr_MAC_Mgmt_MIB {
	ux_uint8_t	aPrivacy_Option_Implemented;
	ux_uint8_t	aWEP_Default;
	ux_uint8_t	aExclude_Unencrypted;
	ux_uint8_t	aAssociated_State;

	ux_uint8_t	aAuthentication_Algorithms[0];	/* XXX */
	ux_uint8_t	aAuthentication_Type;
	
	ux_uint8_t	aPrivacy_Invoked;
	ux_uint32_t	aDefault_WEP_Key[AM79C930_NUM_DEFAULT_WEP_KEYS];
	ux_uint32_t	aICV_Error_Count;
	ux_uint32_t	aWEP_Key_Mapping[AM79C930_NUM_WEP_KEY_MAPPINGS];
	ux_uint48_t	aKnown_APs[AM79C930_NUM_KNOWN_APS];
} __attribute__((packed));	/* GCC extension */

#define	AM79C930_PWR_LVL_TABLE_SIZE	4

#define	Am79C930_PHY_MIB_STRUCTSIZE 32
struct	Am79C930_PHY_MIB {
	ux_uint16_t	aSlot_Time;
	ux_uint16_t	aSIFS;
	ux_uint16_t	aMPDU_Maximum;
	ux_uint16_t	aHop_Time;
	ux_uint8_t	aSuprt_Data_Rates[4];
	ux_uint8_t	aCurrent_Reg_Domain;
#define	AM79C930_PHY_MIB_CURRENT_REG_DOMAIN_FCC		0x10
#define	AM79C930_PHY_MIB_CURRENT_REG_DOMAIN_DOC		0x20
#define	AM79C930_PHY_MIB_CURRENT_REG_DOMAIN_ETSI	0x30
#define	AM79C930_PHY_MIB_CURRENT_REG_DOMAIN_SPAIN	0x31
#define	AM79C930_PHY_MIB_CURRENT_REG_DOMAIN_FRANCE	0x32
#define	AM79C930_PHY_MIB_CURRENT_REG_DOMAIN_MKK		0x40

	ux_uint8_t	aPreamble_Lngth;
	ux_uint8_t	aPLCP_Hdr_Lngth;
	ux_uint16_t	Pwr_Up_Time[AM79C930_PWR_LVL_TABLE_SIZE];
	ux_uint8_t	IEEE_PHY_Type;
#define	AM79C930_PHY_MIB_IEEE_PHY_TYPE_FH		1
#define	AM79C930_PHY_MIB_IEEE_PHY_TYPE_DS		2
#define	AM79C930_PHY_MIB_IEEE_PHY_TYPE_IR		3
	ux_uint64_t	RCR_33A_Bits;
} __attribute__((packed));	/* GCC extension */

/* 802.11 mac header */

#define	Am79C930_80211_Header_STRUCTSIZE 24
struct	Am79C930_80211_Header {
	ux_uint16_t	Frame_Control;
	ux_uint16_t	Duration_ID;
	ux_uint48_t	Address[3];
	ux_uint16_t	Sequence_Control;
};

/* be careful around endian matter... we assume network byte order. */
#define	AM79C930_80211HDR_FC_PROTOCOL_VERSION_MASK	(3<<0)
#define	AM79C930_80211HDR_FC_PROTOCOL_VERSION		(0<<0)
#define	AM79C930_80211HDR_FC_TYPE_MASK			(3<<2)
#define	AM79C930_80211HDR_FC_TYPE_MANAGEMENT		(0<<2)
#define	AM79C930_80211HDR_FC_TYPE_CONTROL		(1<<2)
#define	AM79C930_80211HDR_FC_TYPE_DATA			(2<<2)
#define	AM79C930_80211HDR_FC_SUBTYPE_MASK		(15<<4)
#define	AM79C930_80211HDR_FC_SUBTYPE_PROBE_RESPONSE	(5<<4)
#define	AM79C930_80211HDR_FC_SUBTYPE_BEACON		(8<<4)
#define	AM79C930_80211HDR_FC_TO_DS			(1<<8)
#define	AM79C930_80211HDR_FC_FROM_DS			(1<<9)
#define	AM79C930_80211HDR_FC_MORE_FRAG			(1<<10)
#define	AM79C930_80211HDR_FC_RETRY			(1<<11)
#define	AM79C930_80211HDR_FC_PWR_MGT			(1<<12)
#define	AM79C930_80211HDR_FC_MORE_DATA			(1<<13)
#define	AM79C930_80211HDR_FC_WEP			(1<<14)
#define	AM79C930_80211HDR_FC_ORDER			(1<<15)

#define	AM79C930_80211HDR_DI_FIXED_VALUE		0x8000
#define	AM79C930_80211HDR_DI_AID_IN_PS_POLL_FLAG	0xc000

#define	AM79C930_80211HDR_SC_FRAGMENT_NUMBER_MASK	(15<<0)
#define	AM79C930_80211HDR_SC_FRAGMENT_NUMBER_SHIFT	0
#define	AM79C930_80211HDR_SC_SEQUENCE_NUMBER_MASK	(0xfff<<4)
#define	AM79C930_80211HDR_SC_SEQUENCE_NUMBER_SHIFT	4

#define	Am79C930_80211_BeaconHeader_STRUCTSIZE 12
struct	Am79C930_80211_BeaconHeader {
	ux_uint64_t timestamp;
	ux_uint16_t beacon_interval;
	ux_uint16_t capability_info;
};

#define	AM79C930_80211_ELMID_SSID			0
#define	AM79C930_80211_ELMID_SUPPORTEDRATE		1
#define	AM79C930_80211_ELMID_FH_PARAMSET		2
#define	AM79C930_80211_ELMID_DS_PARAMSET		3
#define	AM79C930_80211_ELMID_CF_PARAMSET		4
#define	AM79C930_80211_ELMID_TIM			5
#define	AM79C930_80211_ELMID_IBSS_PARAMSET		6
#define	AM79C930_80211_ELMID_CHALLENGETEXT		16

/* EOF */
